Module context

Module context 

Structs

ComputeLayoutCx
DragState
EventCx
A bundle of helper methods to be used by View::event handlers
InteractionState
LayoutCx
Holds current layout state for given position in the tree. You’ll use this in the View::layout implementation to call layout_node on children and to access any font
PaintCx
StyleCx
UpdateCx

Enums

PaintState

Type Aliases

EventCallback
MenuCallback
ResizeCallback